Autotest Frontend

Frontend | Admin | Results DB | Documentation

Owner: |  | Name: |

Fetch job by ID:
Label:
Owner:
Priority:
Created:
Timeout: hours
Max runtime: hours
Email List:
Run verify:
Reboot options: before job, after job
Drone set:
Include failed repair results:
Dependencies:
Synchronization count:
Status:
Full results (new results interface) (triage failures) (raw results logs)
Hosts
Create Job Help

Job name: |  |
Priority: |  |
Kernel(s): |  | Kernel Specification Help
Kernel "cmdline": |
Timeout (hours): |  |
Max runtime (hours): |  |
Email List: |  |
Skip verify: |  |
Reboot before: |  |
Reboot after: |  |
Include failed repair results: |  |
Hostless: |  |
Reserve Hosts: |  |
Drone set: |
Tests: |
Profilers: |

Fetch host:
Platform:
Other labels:
ACLs:
Status:
Locked:
Protection level:
Current profile:
Jobs for this host: